# SEC07-BP04: Define data lifecycle management

## Description

Retention, archival, deletion.

## Implementation Guidance

- Retention policies by classification
- Archival procedures
- Secure deletion processes
- Data expiry automation
- Legal hold capabilities

## Risk Level

Medium - Data retained too long increases risk.
